<div align="center">

# SEGFAST

<a href="#installation">Installation</a> • <a href="#getting-started">Getting Started</a>

</div>

---

**segfast** is a library for interacting with SEG-Y seismic data.